@@ -1,8 +1,5 @@
 package Data::Unixish::Apply;
 
-our $DATE = '2019-10-26'; # DATE
-our $VERSION = '1.572'; # VERSION
-
 use 5.010;
 use strict;
 use warnings;
@@ -12,6 +9,11 @@ use Data::Unixish::Util qw(%common_args filter_args);
 use Module::Load;
 use Package::Util::Lite qw(package_exists);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-09-23'; # DATE
+our $DIST = 'Data-Unixish'; # DIST
+our $VERSION = '1.573'; # VERSION
+
 our %SPEC;
 
 $SPEC{apply} = {
@@ -92,7 +94,7 @@ sub apply {
         my $fn = "Data::Unixish::$fn0\::$fnl";
         return [500, "Subroutine &$fn not defined"] unless defined &$fn;
 
-        no strict 'refs';
+        no strict 'refs'; ## no critic: TestingAndDebugging::ProhibitNoStrict
         my $res = $fn->(%$fargs, in=>$in, out=>$out);
         unless ($res->[0] == 200) {
             return [500, "Function $fn0 did not return success: ".
@@ -118,7 +120,7 @@ Data::Unixish::Apply - Apply one or more dux functions
 
 =head1 VERSION
 
-This document describes version 1.572 of Data::Unixish::Apply (from Perl distribution Data-Unixish), released on 2019-10-26.
+This document describes version 1.573 of Data::Unixish::Apply (from Perl distribution Data-Unixish), released on 2023-09-23.
 
 =head1 SYNOPSIS
 
@@ -137,7 +139,7 @@ This document describes version 1.572 of Data::Unixish::Apply (from Perl distrib
 
 Usage:
 
- apply(%args) -> [status, msg, payload, meta]
+ apply(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Apply one or more dux functions.
 
@@ -165,16 +167,19 @@ Example:
 
 =item * B<in>* => I<any>
 
+(No description)
+
+
 =back
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -186,6 +191,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixi
 
 Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023, 2019, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Unixish>
@@ -194,15 +228,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2019, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
