@@ -1,9 +1,5 @@
 package Data::Unixish::splice;
 
-our $DATE = '2019-10-26'; # DATE
-our $DIST = 'Data-Unixish'; # DIST
-our $VERSION = '1.572'; # VERSION
-
 use 5.010001;
 use strict;
 use syntax 'each_on_array'; # to support perl < 5.12
@@ -12,6 +8,11 @@ use warnings;
 
 use Data::Unixish::Util qw(%common_args);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-09-23'; # DATE
+our $DIST = 'Data-Unixish'; # DIST
+our $VERSION = '1.573'; # VERSION
+
 our %SPEC;
 
 $SPEC{splice} = {
@@ -87,7 +88,7 @@ Data::Unixish::splice - Perform Perl splice() on array
 
 =head1 VERSION
 
-This document describes version 1.572 of Data::Unixish::splice (from Perl distribution Data-Unixish), released on 2019-10-26.
+This document describes version 1.573 of Data::Unixish::splice (from Perl distribution Data-Unixish), released on 2023-09-23.
 
 =head1 SYNOPSIS
 
@@ -104,7 +105,7 @@ In Perl:
 
 Usage:
 
- splice(%args) -> [status, msg, payload, meta]
+ splice(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Perform Perl splice() on array.
 
@@ -120,24 +121,31 @@ Input stream (e.g. array or filehandle).
 
 =item * B<length> => I<uint>
 
+(No description)
+
 =item * B<list> => I<array[str]>
 
+(No description)
+
 =item * B<offset>* => I<uint>
 
+(No description)
+
 =item * B<out> => I<any>
 
 Output stream (e.g. array or filehandle).
 
+
 =back
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -149,14 +157,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixi
 
 Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Unixish>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 Perl's C<splice> in L<perlfunc>
@@ -169,11 +169,37 @@ L<Data::Unixish::join>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
+This software is copyright (c) 2023, 2019, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Unixish>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
